
/* Chrysalide - Outil d'analyse de fichiers binaires
 * core.c - chargement et déchargement des mécanismes internes de l'architecture Dalvik
 *
 * Copyright (C) 2016-2017 Cyrille Bagard
 *
 *  This file is part of Chrysalide.
 *
 *  Chrysalide is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Chrysalide is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Foobar.  If not, see <http://www.gnu.org/licenses/>.
 */


#include "core.h"


#include "register.h"
#include "operands/args.h"
#include "operands/pool.h"
#include "operands/register.h"



/******************************************************************************
*                                                                             *
*  Paramètres  : -                                                            *
*                                                                             *
*  Description : Met en place les mécanismes internes de l'architecture.      *
*                                                                             *
*  Retour      : Bilan de l'opération.                                        *
*                                                                             *
*  Remarques   : -                                                            *
*                                                                             *
******************************************************************************/

bool init_dalvik_core(void)
{
    bool result;                            /* Bilan à renvoyer            */

    result = true;

    result &= init_dalvik_register_sharing();

    result &= init_dalvik_args_operand_sharing();
    result &= init_dalvik_pool_operand_sharing();
    result &= init_dalvik_register_operand_sharing();

    return result;

}


/******************************************************************************
*                                                                             *
*  Paramètres  : -                                                            *
*                                                                             *
*  Description : Imprime des statistiques quant aux partages dans l'archi.    *
*                                                                             *
*  Retour      : -                                                            *
*                                                                             *
*  Remarques   : -                                                            *
*                                                                             *
******************************************************************************/
#ifdef DEBUG_DUMP_STATS
void dump_dalvik_share_stats(void)
{
    dump_dalvik_register_share_stats();

    dump_dalvik_args_operand_share_stats();
    dump_dalvik_pool_operand_share_stats();
    dump_dalvik_register_operand_share_stats();

}
#endif


/******************************************************************************
*                                                                             *
*  Paramètres  : -                                                            *
*                                                                             *
*  Description : Supprime les mécanismes internes de l'architecture Dalvik.   *
*                                                                             *
*  Retour      : -                                                            *
*                                                                             *
*  Remarques   : -                                                            *
*                                                                             *
******************************************************************************/

void exit_dalvik_core(void)
{
    exit_dalvik_register_sharing();

    exit_dalvik_args_operand_sharing();
    exit_dalvik_pool_operand_sharing();
    exit_dalvik_register_operand_sharing();

}
