
/* Chrysalide - Outil d'analyse de fichiers binaires
 * break.h - prototypes pour la manipulation des points d'arrêt
 *
 * Copyright (C) 2010-2017 Cyrille Bagard
 *
 *  This file is part of Chrysalide.
 *
 *  Chrysalide is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Chrysalide is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Foobar.  If not, see <http://www.gnu.org/licenses/>.
 */


#ifndef _DEBUG_BREAK_H
#define _DEBUG_BREAK_H


#include <glib-object.h>
#include <stdbool.h>


#include "../arch/archbase.h"
#include "../glibext/proto.h"



/* --------------------------- GESTION DES POINTS D'ARRET --------------------------- */


#define G_TYPE_BREAK_POINT               g_break_point_get_type()
#define G_BREAK_POINT(obj)               (G_TYPE_CHECK_INSTANCE_CAST((obj), g_break_point_get_type(), GBreakPoint))
#define G_IS_BREAK_POINT(obj)            (G_TYPE_CHECK_INSTANCE_TYPE((obj), g_break_point_get_type()))
#define G_BREAK_POINT_GET_IFACE(inst)    (G_TYPE_INSTANCE_GET_INTERFACE((inst), g_break_point_get_type(), GBreakPointIface))
#define G_BREAK_POINT_GET_CLASS(obj)     (G_TYPE_INSTANCE_GET_CLASS((obj), G_TYPE_BREAK_POINT, GBreakPointClass))


/* Propriétés d'un point d'arrêt (instance) */
typedef struct _GBreakPoint GBreakPoint;

/* Propriétés d'un point d'arrêt (classe) */
typedef struct _GBreakPointClass GBreakPointClass;


/* Indique le type défini pour des propriétés d'un point d'arrêt. */
GType g_break_point_get_type(void);

/* Construit un nouveau point d'arrêt. */
GBreakPoint *g_break_point_new(vmpa_t);

/* Fournit l'adresse associée à un point d'arrêt. */
vmpa_t g_break_point_get_address(const GBreakPoint *);



/* ---------------------------- GROUPE DE POINTS D'ARRET ---------------------------- */


#define G_TYPE_BREAK_GROUP               g_break_group_get_type()
#define G_BREAK_GROUP(obj)               (G_TYPE_CHECK_INSTANCE_CAST((obj), g_break_group_get_type(), GBreakGroup))
#define G_IS_BREAK_GROUP(obj)            (G_TYPE_CHECK_INSTANCE_TYPE((obj), g_break_group_get_type()))
#define G_BREAK_GROUP_GET_IFACE(inst)    (G_TYPE_INSTANCE_GET_INTERFACE((inst), g_break_group_get_type(), GBreakGroupIface))
#define G_BREAK_GROUP_GET_CLASS(obj)     (G_TYPE_INSTANCE_GET_CLASS((obj), G_TYPE_BREAK_GROUP, GBreakGroupClass))


/* Propriétés d'un groupe de points d'arrêt (instance) */
typedef struct _GBreakGroup GBreakGroup;

/* Propriétés d'un groupe de points d'arrêt (classe) */
typedef struct _GBreakGroupClass GBreakGroupClass;


/* Indique le type défini pour les groupes de points d'errêt. */
GType g_break_group_get_type(void);

/* Construit un nouveau groupe de points d'arrêt. */
GBreakGroup *g_break_group_new(void);

/* Fournit la désignation humaine associée à un groupe. */
const char *g_break_group_get_name(const GBreakGroup *);

/* Définit la désignation humaine à associer à un groupe. */
void g_break_group_set_name(GBreakGroup *, const char *);

/* Indique si une adresse donnée est gérée dans un groupe. */
bool g_break_group_has_address(const GBreakGroup *, vmpa_t);

/* Ajoute ou supprime un point d'arrêt dans un groupe. */
void g_break_group_toggle_breakpoint(GBreakGroup *, vmpa_t);

/* Parcourt l'ensemble des points d'arrêt d'un groupe donné. */
void g_break_group_for_each(GBreakGroup *, GExtFunc, gpointer);



#endif  /* _DEBUG_BREAK_H */
